//Modify LEDButton sample
// 2014/8/29
//
// Button & LED sample with RCBController
//
// RCBController (iOS app)
// https://itunes.apple.com/app/rcbcontroller/id689724127?mt=8
//
// by Micono Utilities
// micono@mac.com

/*
This RFduino sketch demonstrates a full bi-directional Bluetooth Low
Energy 4 connection between an iPhone application and an RFduino.

This sketch works with the rfduinoLedButton iPhone application.

The button on the iPhone can be used to turn the green led on or off.
The button state of button 1 is transmitted to the iPhone and shown in
the application.
*/

#include <RFduinoBLE.h>

// pin 3 on the RGB shield is the red led
// (can be turned on/off from the iPhone app)
int ledR = 2;
int ledG = 3;
int ledB = 4;

// pin 5 on the RGB shield is button 1
// (button press will be shown on the iPhone app)
int button = 5;

// debounce time (in ms)
int debounce_time = 10;

// maximum debounce timeout (in ms)
int debounce_timeout = 100;

void setup() {
  // led turned on/off from the iPhone app
  pinMode(ledR, OUTPUT);
  pinMode(ledG, OUTPUT);
  pinMode(ledB, OUTPUT);

  // button press will be shown on the iPhone app)
  pinMode(button, INPUT);

  // this is the data we want to appear in the advertisement
  // (the deviceName length plus the advertisement length must be <= 18 bytes
  RFduinoBLE.advertisementData = "ledbtn";
  
  // start the BLE stack
  RFduinoBLE.begin();
}

int debounce(int state)
{
  int start = millis();
  int debounce_start = start;
  
  while (millis() - start < debounce_timeout)
    if (digitalRead(button) == state)
    {
      if (millis() - debounce_start >= debounce_time)
        return 1;
    }
    else
      debounce_start = millis();

  return 0;
}

int delay_until_button(int state)
{
  // set button edge to wake up on
  if (state)
    RFduino_pinWake(button, HIGH);
  else
    RFduino_pinWake(button, LOW);
    
  do
    // switch to lower power mode until a button edge wakes us up
    RFduino_ULPDelay(INFINITE);
  while (! debounce(state));
  
  // if multiple buttons were configured, this is how you would determine what woke you up
  if (RFduino_pinWoke(button))
  {
    // execute code here
    RFduino_resetPinWake(button);
  }
}

const char *pba={"Push A"};
const char *uba={"Up A"};

void loop() {
  delay_until_button(HIGH);
  RFduinoBLE.send(pba,6);//RFduinoBLE.send(1);
  
  delay_until_button(LOW);
  RFduinoBLE.send(uba,4);//RFduinoBLE.send(0);
}

void RFduinoBLE_onDisconnect()
{
  // don't leave the led on if they disconnect
  digitalWrite(ledR, LOW);
  digitalWrite(ledG, LOW);
  digitalWrite(ledB, LOW);
}

void RFduinoBLE_onReceive(char *data, int len)
{
  // if the first byte is 0x01 / on / true
  if(data[1]&64 || data[1]&16 || data[1]&128)
    digitalWrite(ledR, HIGH);
  else
    digitalWrite(ledR, LOW);
    
  if(data[1]&32 || data[1]&16 || data[1]&128)
    digitalWrite(ledG, HIGH);
  else
    digitalWrite(ledG, LOW);
    
  if(data[0]&1 || data[1]&128)
    digitalWrite(ledB, HIGH);
  else
    digitalWrite(ledB, LOW);
  
}
